@@ -20,7 +20,6 @@ import re
 import math
 from os import path
 from calculate.lib.utils.dracut import Dracut
-from calculate.lib import cl_overriding
 import sys
 import getpass
 from types import StringType
@@ -83,9 +82,9 @@ class _warning(object):
             self.warning.pop()
 
 
-def genpassword(passlen=9):
+def genpassword(passlen=9, chars=string.ascii_letters + string.digits):
     """Return random charset specified lenght (passlen)"""
-    return ''.join(map(lambda x: choice(string.ascii_letters + string.digits),
+    return ''.join(map(lambda x: choice(chars),
                        xrange(0, passlen)))
 
 
@@ -100,33 +99,6 @@ def getpathenv():
 
 from files import process, listDirectory
 
-
-def getUserPassword(flag="dialog", pwDialog=False):
-    """Получить пароль у пользователя
-
-    flag - опция "dalog" или "stdin" - откуда получаем пароль
-    pwDialog  - структура для вывода приглашения в режиме диалога
-    """
-    if flag == "dialog":
-        if not pwDialog:
-            pwDialog = [_("New password"), _("Retype the new password")]
-        pwdA = getpass.getpass(pwDialog[0] + _(":"))
-        pwdB = getpass.getpass(pwDialog[1] + _(":"))
-    elif flag == "stdin":
-        pwdA = sys.stdin.readline().rstrip()
-        pwdB = sys.stdin.readline().rstrip()
-    else:
-        cl_overriding.printERROR(_("ERROR in function getUserPassword, "
-                                   "incorrect option 'flag=%s'") % flag)
-        return False
-    if not pwdA or not (pwdA == pwdB):
-        cl_overriding.printERROR(_("ERROR") + ": " +
-                                 _("wrong password") + ": " + _("try again"))
-        return False
-    userPwd = pwdA
-    return userPwd
-
-
 def cmpVersion(v1, v2):
     """Compare versions specified by tuple or string"""
     if isinstance(v1, StringType):
@@ -159,28 +131,6 @@ def getTupleVersion(ver):
     return [vers, revision]
 
 
-def appendProgramToEnvFile(nameProg, objVar):
-    """Append name program to variable cl-merges and
-
-    save /etc/calculate/calculate.env """
-    if not objVar.AppendToList("cl_merges", nameProg, force=True):
-        return False
-    if not objVar.WriteList("cl_merges", force=True):
-        return False
-    return True
-
-
-def removeProgramToEnvFile(nameProg, objVar):
-    """Remove name program from variable cl-merges and save
-
-    /etc/calculate/calculate.env"""
-    if not objVar.RemoveToList("cl_merges", nameProg, force=True):
-        return False
-    if not objVar.WriteList("cl_merges", force=True):
-        return False
-    return True
-
-
 def getInstalledVideo(prefix="/"):
     """Get installed video drivers"""
     x11Drivers = path.join(prefix, "usr/lib/xorg/modules/drivers")
@@ -269,6 +219,7 @@ class CmdlineParams(object):
     Composite = "composite"
     Domain = "domain"
     DomainPassword = "domain_pw"
+    Audio = "audio"
 
 
 def getValueFromCmdLine(option, num=None):
@@ -288,7 +239,8 @@ def getValueFromCmdLine(option, num=None):
         CmdlineParams.Video,
         CmdlineParams.Composite,
         CmdlineParams.Domain,
-        CmdlineParams.DomainPassword)
+        CmdlineParams.DomainPassword,
+        CmdlineParams.Audio)
     # try get timezone from kernel calculate param
     try:
         if num is None:
@@ -400,7 +352,7 @@ def getVideoFromModules():
                   'i915': 'intel',
                   'fglrx': 'fglrx',
                   'nvidia': 'nvidia',
-                  #'amdgpu': 'amdgpu',
+                  # 'amdgpu': 'amdgpu',
                   'via': 'via',
                   'vmware': 'vmware'}
     for module, videodrv in mapModules.items():
