@@ -1512,6 +1512,7 @@ def tar_unpack(archfile, target_dn):
     except (tarfile.TarError, IOError, OSError) as e:
         raise FilesError(_("Failed to create tarball: %s") % str(e))
 
+
 class RsyncOptions(object):
     Xattrs = "--xattrs"
     KeepDirLinks = "--keep-dirlinks"
@@ -1519,6 +1520,10 @@ class RsyncOptions(object):
     Archive = "--archive"
     FilesFromStdin = "--files-from=-"
 
+    @classmethod
+    def Chown(self, uid, gid):
+        return "--chown={0}:{1}".format(uid, gid)
+
     # опции используемые при "скрывании пакета"
     # --keep-dirlinks решает проблему восстановления "скрытых" файлов
     HidePackageOpts = (Xattrs, KeepDirLinks, OneFileSystem, Archive)
